<?php

namespace Drupal\crowdsec\Commands;

use CrowdSec\CapiClient\ClientException;
use Drupal\crowdsec\Client;
use Drupal\crowdsec\Form\Settings;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 */
class CrowdSec extends DrushCommands {

  /**
   * The CrowdSec client service.
   *
   * @var \Drupal\crowdsec\Client
   */
  protected Client $client;

  /**
   * Constructs the CrowdSec event subscriber service.
   *
   * @param \Drupal\crowdsec\Client $client
   *   The CrowdSec client service.
   */
  public function __construct(Client $client) {
    $this->client = $client;
    parent::__construct();
  }

  /**
   * Enroll CrowdSec account.
   *
   * @param string $name
   *   Name of this instance.
   * @param string $enrollkey
   *   Enroll key you obtained from the CrowdSec console.
   *
   * @usage crowdsec:enroll NAME ENROLLKEY
   *   Enroll CrowdSec account.
   *
   * @command crowdsec:enroll
   */
  public function enroll(string $name, string $enrollkey): void {
    $this->client->watcher()->enroll($name, TRUE, $enrollkey);
  }

  /**
   * Collect data from CrowdSec.
   *
   * @usage crowdsec:collect
   *   Collect data from CrowdSec.
   *
   * @command crowdsec:collect
   */
  public function collect(): void {
    $this->client->refresh();
  }

  /**
   * Test CrowdSec by sending a signal to ban an IP address.
   *
   * @param string $ip
   *   The IP address to signal.
   *
   * @usage crowdsec:test:signal 1.2.3.4
   *   Test CrowdSec by sending a signal to ban the IP 1.2.3.4.
   *
   * @command crowdsec:test:signal
   */
  public function testSignalIp(string $ip): void {
    $watcher = $this->client->watcher();
    try {
      $signal = $watcher->createSignal(Settings::SCENARIO_FLOOD, $ip, NULL, NULL);
      $watcher->pushSignals([$signal]);
    }
    catch (ClientException $e) {
      $this->logger->critical($e->getMessage());
    }
  }

  /**
   * Test CrowdSec by verifying an IP address.
   *
   * @param string $ip
   *   The IP address to verify.
   *
   * @usage crowdsec:test:ip 1.2.3.4
   *   Test CrowdSec by verifying the IP 1.2.3.4.
   *
   * @command crowdsec:test:ip
   */
  public function testIp(string $ip): void {
    print($this->client->verifyIp($ip));
  }

}
